%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                  %
%          INPUT FILE FOR SIMULATION OF STEAM REFORMER             %
%                FOR PRODUCTION OF SYNTHESIS GAS                   %
%                                                                  %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global GASCONST Tref Ncomp Pic h Rp rhop eps Dp TEMPout LAMBDAst RADIUSi lambda T ...
    RADIUSo MMASS AJ AX ACTEN ENT298 ENT948 ADENT CP LAMBDA B S sumny uin Yic N tau dpore B0

%Initial data
%-------------------------------------------------------------------
Tref = 800;                % Initial temperature      [K]
Pic = 29e5;               % Initial pressure         [Pa]


% Constants
%-------------------------------------------------------------------
GASCONST  = 8.3145E3;     % Gas constant             [J/kmoleK]
Ncomp     = 6;            % Number of components     [-]
N         = 40;           % Number of radial points in the pellet


% Catalyst data
%-------------------------------------------------------------------
rhop   = 2300;          % Density catalyst         [kgcat/m^3]
eps    = 0.528;           % Pore fraction            [-]
Dp     = 0.0173;          % Particle diameter        [m]
Rp     = Dp/2;            % Particle radius          [m]
lambda  = 25;              % Particle conductivity    [W/mK]
tau=3.5;
dpore=40*10^-9;
B0=eps/tau*dpore^2/32;
h=4158;

% Initial massfraction of the components             [-]
%-------------------------------------------------------------------
Yic(1) = 0.21218;       % CH4
Yic(2) = 6.3581E-005;       % CO
Yic(3) = 0.0080931;       % CO2
Yic(4) = 0.025567;       % H2
Yic(5) = 0.040755;       % N2
Yic(6) = 0.71335;       % H2O


% Molemass of the components                         [kg/kmole]
%-------------------------------------------------------------------

MMASS(1) = 16.04;         % Molemass CH4
MMASS(2) = 28.01;         % Molemass CO
MMASS(3) = 44.01;         % Molemass CO2
MMASS(4) =  2.02;         % Molemass H2
MMASS(5) = 28.01;         % Molemass N2
MMASS(6) = 18.02;         % Molemass H2O

% Preexponential factors for the rate constants      [kmole/kgcat h]
%-------------------------------------------------------------------
AJ(1) = 4.255E15;         % Factor for rx. 1
AJ(2) = 1.955E6 ;         % Factor for rx. 2
AJ(3) = 1.020E15;         % Factor for rx. 3


% Preexponential factors for the adsorbtion constants
%-------------------------------------------------------------------
AX(1) = 6.65E-4;          % Factor for CH4           [bar^-1]
AX(2) = 8.23E-5;          % Factor for CO            [bar^-1]
AX(3) = 6.12E-9;          % Factor for H2            [bar^-1]
AX(4) = 1.77E5;           % Factor for H2O           [-]


% Activation energies for the reactions              [J/kmole]
%-------------------------------------------------------------------
ACTEN(1) = 240.1E6;       % Activation energy for rx. 1
ACTEN(2) = 67.13E6;       % Activation energy for rx. 2
ACTEN(3) = 243.9E6;       % Activation energy for rx. 3


% Reaction enthalpies at 298K                        [J/kmole]
%-------------------------------------------------------------------
ENT298(1) = 206.1E6;      % Enthalpy for rx. 1 
ENT298(2) = -41.15E6;     % Enthalpy for rx. 2
ENT298(3) = 164.9E6;      % Enthalpy for rx. 3


% Reaction enthalpies at 948K                        [J/kmole]
%-------------------------------------------------------------------
ENT948(1) = 224.E6;       % Enthalpy for rx. 1
ENT948(2) = -37.30E6;     % Enthalpy for rx. 2
ENT948(3) = 187.5E6;      % Enthalpy for rx. 3


% Adsorption enthalpies                              [J/kmole]
%-------------------------------------------------------------------
ADENT(1) =-38.28E6;       % Enthalpy for adsorption of CH4
ADENT(2) =-70.65E6;       % Enthalpy for adsorption of CO
ADENT(3) =-82.90E6;       % Enthalpy for adsorption of H2
ADENT(4) = 88.68E6;       % Enthalpy for adsorption of H2O


% Heat capasity coefficients for the components        
%-------------------------------------------------------------------
CP(1,1) = 1.925E4;        % 1. coefficient for CH4   [J/kmoleK]
CP(1,2) = 5.213E1;        % 2. coefficient for CH4   [J/kmoleK^2]
CP(1,3) = 1.197E-2;       % 3. coefficient for CH4   [J/kmoleK^3]
CP(1,4) =-1.132E-5;       % 4. coefficient for CH4   [J/kmoleK^4]

CP(2,1) = 3.087E4;        % 1. coefficient for CO    [J/kmoleK]
CP(2,2) =-1.285E1;        % 2. coefficient for CO    [J/kmoleK^2]
CP(2,3) = 2.789E-2;       % 3. coefficient for CO    [J/kmoleK^3]
CP(2,4) =-1.272E-5;       % 4. coefficient for CO    [J/kmoleK^4]

CP(3,1) = 1.980E4;        % 1. coefficient for CO2   [J/kmoleK]
CP(3,2) = 7.344E1;        % 2. coefficient for CO2   [J/kmoleK^2]
CP(3,3) =-5.602E-2;       % 3. coefficient for CO2   [J/kmoleK^3]
CP(3,4) = 1.715E-5;       % 4. coefficient for CO2   [J/kmoleK^4]

CP(4,1) = 2.714E4;        % 1. coefficient for H2    [J/kmoleK]
CP(4,2) = 0.9274E1;       % 2. coefficient for H2    [J/kmoleK^2]
CP(4,3) =-1.381E-2;       % 3. coefficient for H2    [J/kmoleK^3]
CP(4,4) = 0.7645E-5;      % 4. coefficient for H2    [J/kmoleK^4]

CP(5,1) = 3.115E4;        % 1. coefficient for N2    [J/kmoleK]
CP(5,2) =-1.357E1;        % 2. coefficient for N2    [J/kmoleK^2]
CP(5,3) = 2.680E-2;       % 3. coefficient for N2    [J/kmoleK^3]
CP(5,4) =-1.168E-5;       % 4. coefficient for N2    [J/kmoleK^4]

CP(6,1) = 3.224E4;        % 1. coefficient for H2O   [J/kmoleK]
CP(6,2) = 0.1924E1;       % 2. coefficient for H2O   [J/kmoleK^2]
CP(6,3) = 1.055E-2;       % 3. coefficient for H2O   [J/kmoleK^3]
CP(6,4) = 0.3596E-5;      % 4. coefficient for H2O   [J/kmoleK^4]


% Viscosity coefficients
%-------------------------------------------------------------------
B(1) = 1.00E-6;           % Coefficient for CH4      [kg/msK^0.5]
B(2) = 1.50E-6;           % Coefficient for CO       [kg/msK^0.5]
B(3) = 1.50E-6;           % Coefficient for CO2      [kg/msK^0.5]
B(4) = 0.65E-6;           % Coefficient for H2       [kg/msK^0.5]
B(5) = 1.40E-6;           % Coefficient for N2       [kg/msK^0.5]
B(6) = 1.74E-6;           % Coefficient for H2O      [kg/msK^0.5]


S(1) = 165;               % Coefficient for CH4      [K]
S(2) = 220;               % Coefficient for CO       [K]
S(3) = 220;               % Coefficient for CO2      [K]
S(4) =  67;               % Coefficient for H2       [K]
S(5) = 108;               % Coefficient for N2       [K]
S(6) = 626;               % Coefficient for H2O      [K]


%inital values:
Flux=[zeros(N,6)];
tol=2*10^-11;
residual=1;
%C=Pic./GASCONST./T;
Cref=Pic./GASCONST./Tref;
%Cl=C/Cref;
Pl=ones(N,1);
Cl=ones(N,1);
u=ones(N,1);
DCvelconvRelaxed=zeros(N,N);
vconvrelaxed=zeros(N,1);
T=ones(N,1)*Tref;
itcount=1;

%Mass cont
Cref=Pic./GASCONST./Tref;
%Cl=C/Cref;
Pl=ones(N,1);
v=zeros(N,1);
Mavref=MMASS*Yic';
Mavl=ones(N,1);
RHOref=Pic.*Mavref./GASCONST./Tref;
RHOl=ones(N,1);
FOLD=zeros(N,1);
DCvelconvRelaxed=zeros(N,N);

