%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%    Function that calculates the viscosity of the gas mixture   
%%%    in every interpolation points. 
%%%         KUMAR RANJAN ROUT, rout@nt.ntnu.no
%%%                                                                 
%%%    Input:                                                     
%%%    T - Temperature, vector [K]                                                                              
%%%    Yy - mass fraction, matrix [-]                                                                      
%%%    n - number of interpolation points                         
%%%    Output:                                                    
%%%    VISg - viscosity of components [kg/sm] 
%%%    vis_comp - viscosity of components [kg/sm] 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [VISg, vis_comp] = viscosity(T,Yy,N) 

global Ncomp B S

%%% viscosity for the components
%%% columns --> components
%%% rows --> positions, nodal points, calculation points
for j = 1:Ncomp 
    vis_comp(:,j)= T.^(1.5)*B(1,j)./(T+S(1,j));
end


for i = 1:N
    VISg(i,1) = sum( Yy(i,:).*vis_comp(i,:) );
end
